pub struct Waveform {
paintable: WaveformPaintable,
position: Cell<f32>,
animation: OnceCell<TimedAnimation>,
hover_position: Cell<Option<f32>>,
paintable_cache: RefCell<Option<Paintable>>,
}Fields
paintable: WaveformPaintableThe paintable that draws the waveform.
position: Cell<f32>The current position in the audio stream.
Must be a value between 0 and 1.
animation: OnceCell<TimedAnimation>The animation for the transition between waveforms.
hover_position: Cell<Option<f32>>The current hover position, if any.
paintable_cache: RefCell<Option<Paintable>>The cached paintable.
We only need to redraw it when the waveform changes of the widget is resized.
Implementations
Sourceimpl Waveform
impl Waveform
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Waveform
impl Waveform
Sourcepub(super) fn set_waveform(&self, waveform: Vec<f32>)
pub(super) fn set_waveform(&self, waveform: Vec<f32>)
Set the waveform to display.
The values must be normalized between 0 and 1.
Sourcepub(super) fn set_position(&self, position: f32)
pub(super) fn set_position(&self, position: f32)
Set the current position in the audio stream.
Sourcefn animation(&self) -> &TimedAnimation
fn animation(&self) -> &TimedAnimation
The animation for the waveform change.
fn paintable(&self) -> Option<Paintable>
Sourcefn x_coord_to_position(&self, x: f64) -> f32
fn x_coord_to_position(&self, x: f64) -> f32
Convert the given x coordinate on the waveform to a relative position.
Takes into account the text direction.
Returns a value between 0 and 1.
Sourcefn emit_seek(&self, new_position: f32)
fn emit_seek(&self, new_position: f32)
Emit the seek signal with the given new position, if it is
different from the current position.
Sourcefn init_event_controllers(&self)
fn init_event_controllers(&self)
Initialize the event controllers on the waveform.